@@ -1,5 +1,6 @@
 #include <libplatform/libplatform.h>
 #include "V8_types.h"
+#include <fstream>
 
 /* use conditional apis below */
 #define V8_VERSION_TOTAL (V8_MAJOR_VERSION * 100 + V8_MINOR_VERSION)
@@ -191,6 +192,11 @@ void start_v8_isolate(void *dll){
 #else
   platformptr = v8::platform::CreateDefaultPlatform();
   v8::V8::InitializePlatform(platformptr);
+#endif
+#if V8_VERSION_TOTAL > 805 && V8_VERSION_TOTAL < 909
+  /* Flag introduced: https://github.com/v8/v8/commit/ba688c6ec9c
+   * Flag removed: https://github.com/v8/v8/commit/1771e4aaa */
+  v8::V8::SetFlagsFromString("--experimental-wasm-reftypes");
 #endif
   v8::V8::Initialize();
   v8::Isolate::CreateParams create_params;
@@ -199,6 +205,10 @@ void start_v8_isolate(void *dll){
   isolate = v8::Isolate::New(create_params);
   if(!isolate)
     throw std::runtime_error("Failed to initiate V8 isolate");
+
+  v8::Isolate::Scope isolate_scope(isolate);
+  v8::HandleScope handle_scope(isolate);
+
   isolate->AddMessageListener(message_cb);
   isolate->SetFatalErrorHandler(fatal_cb);
 
@@ -326,8 +336,10 @@ std::string version(){
 }
 
 static Rcpp::RObject convert_object(v8::Local<v8::Value> value){
-  if(value.IsEmpty() || value->IsNullOrUndefined()){
+  if(value.IsEmpty() || value->IsUndefined()){
     return R_NilValue;
+  } else if(value->IsNull()){
+    return Rcpp::CharacterVector::create(Rcpp::String("null"));
   } else if(value->IsArrayBuffer() || value->IsArrayBufferView()){
     v8::Local<v8::ArrayBuffer> buffer = value->IsArrayBufferView() ?
     value.As<v8::ArrayBufferView>()->Buffer() : value.As<v8::ArrayBuffer>();
